<?php

/**
 * functions.php
 *
 * The theme's functions and definitions.
 */


/**
 * ----------------------------------------------------------------------------------------
 * 1.0 - Define constants.
 * ----------------------------------------------------------------------------------------
 */

define( 'THEMEROOT', get_stylesheet_directory_uri() );

define( 'IMAGES', THEMEROOT . '/images' );

define( 'SCRIPTS', THEMEROOT . '/js' );

require_once( 'wp_bootstrap_navwalker.php' );


/**
 * ----------------------------------------------------------------------------------------
 * 4.0 - Set up theme default and register various supported features.
 * ----------------------------------------------------------------------------------------
 */


if ( ! function_exists( 'alpha_setup' ) ) {

	function alpha_setup() {

		/**
		 * Make the theme available for translation.
		 */

		$lang_dir = THEMEROOT . '/languages';

		load_theme_textdomain( 'alpha', $lang_dir );


		/**
		 * Add support for post formats.
		 */

//		add_theme_support( 'post-formats',

//			array(

//				'gallery',

//				'link',

//				'image',

//				'quote',

//				'video',

//				'audio'

//			)

//		);


		/**
		 * Add support for automatic feed links.
		 */

		add_theme_support( 'automatic-feed-links' );

		add_theme_support( 'widgets' );


		/**
		 * Add support for post thumbnails.
		 */

		add_theme_support( 'post-thumbnails' );


		/**
		 * Register nav menus.
		 */

		register_nav_menus(

			array(

				'main' => __( 'القائمة الرئيسية', 'alpha' ),
				'footer' => __( ' قائمة الفوتر', 'alpha' )
			)

		);

	}


	add_action( 'after_setup_theme', 'alpha_setup' );

}


/**
 * ----------------------------------------------------------------------------------------
 * 10.0 - Load the custom scripts for the theme.
 * ----------------------------------------------------------------------------------------
 */

if ( ! function_exists( 'alpha_scripts' ) ) {

	function alpha_scripts() {

		// Adds support for pages with threaded comments

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {

			wp_enqueue_script( 'comment-reply' );

		}


		// Register scripts

		wp_register_script( 'bootstrap-js', SCRIPTS . '/bootstrap.min.js', array( 'jquery' ), false, true );
//		wp_register_script( 'viewportchecker', SCRIPTS . '/viewportchecker.js', array( 'jquery' ), false, true );
		wp_register_script( 'wow', SCRIPTS . '/wow.min.js', array( 'jquery' ), false, true );
		wp_register_script( 'owl', SCRIPTS . '/owl.carousel.min.js', array( 'jquery' ), false, true );
		wp_register_script( 'custom', SCRIPTS . '/custom.js', array( 'jquery' ), false, true );


		// Load the custom scripts

		wp_enqueue_script( 'bootstrap-js' );
//		wp_enqueue_script( 'viewportchecker' );
		wp_enqueue_script( 'wow' );
		wp_enqueue_script( 'owl' );
		wp_enqueue_script( 'custom' );


		// Load the stylesheets

		wp_enqueue_style( 'bootstrap', THEMEROOT . '/css/bootstrap.min.css' );
		wp_enqueue_style( 'Fontawesome', THEMEROOT . '/css/font-awesome.min.css' );
		wp_enqueue_style( 'animate', THEMEROOT . '/css/animate.css' );
		wp_enqueue_style( 'owl', THEMEROOT . '/css/owl.carousel.css' );


		if ( is_rtl() ) {


			wp_enqueue_style( 'bootstrap-rtl', THEMEROOT . '/css/bootstrap-rtl.min.css' );

			wp_enqueue_style( 'rtl', THEMEROOT . '/style.css' );


		} else {

			wp_enqueue_style( 'en', THEMEROOT . '/en.css' );

		}


	}


	add_action( 'wp_enqueue_scripts', 'alpha_scripts' );

}


/**
 * ----------------------------------------------------------------------------------------
 * 11.0 - Custom Post Type.
 * ----------------------------------------------------------------------------------------
 */


register_post_type( 'slider', array(

	'public' => true,

	'hierarchical' => false,

	'exclude_from_search' => false,

	'has_archive' => false,

	'rewrite' => array( 'slug' => 'slider' ),

	'capability_type' => 'post',

	'menu_icon' => 'dashicons-images-alt',

	'taxonomies' => array( 'post_tag' ),

	'labels' => array(

		'name' => 'سلايدرز',

		'add_new_item' => 'اضف جديد',

		'singular_name' => 'سلايدر',

		'menu_name' => 'سلايدر',

		'name_admin_bar' => ' سلايدر',

		'all_items' => 'الكل',

		'add_new' => 'اضف جديد',

		'edit_item' => 'تعديل ',

		'new_item' => 'جديد',

		'view_item' => 'مشاهدة ',

		'search_items' => 'بحث ',

		'not_found' => 'لا يوجد سلايدرز',

		'not_found_in_trash' => 'لا يوجد سلايدرز',

		'parent_item_colon' => 'القسم الرئيسي',

	),

	'supports' => array( 'title', 'editor', 'thumbnail' )

) );






register_post_type( 'projects', array(

	'public' => true,

	'hierarchical' => false,

	'exclude_from_search' => false,

	'has_archive' => false,

	'rewrite' => array( 'slug' => 'projects' ),

	'capability_type' => 'post',

	'menu_icon' => 'dashicons-welcome-write-blog',

	'taxonomies' => array( 'post_tag' ),

	'labels' => array(

		'name' => 'اعمالنا',

		'add_new_item' => 'اضف جديد',

		'singular_name' => 'عمل',

		'menu_name' => 'اعمالنا',

		'name_admin_bar' => ' عميل',

		'all_items' => 'الكل',

		'add_new' => 'اضف جديد',

		'edit_item' => 'تعديل ',

		'new_item' => 'جديد',

		'view_item' => 'مشاهدة ',

		'search_items' => 'بحث ',

		'not_found' => 'لا يوجد أعمال',

		'not_found_in_trash' => 'لا يوجد أعمال',

		'parent_item_colon' => 'القسم الرئيسي',

	),

	'supports' => array( 'title', 'thumbnail','editor' )

) );


/*************************************************/
/* Register Taxonami */
/*************************************************/
//add_action( 'init', 'create_sections' );
//
//function create_sections() {
//	register_taxonomy(
//		'sections',
//		'portfolio',
//		array(
//			'label'             => __( 'Portfolio\'s categories' ),
//			'hierarchical'      => true,
//			'show_ui'           => true,
//			'show_admin_column' => true,
//			'show_in_nav_menus' => true,
//			'show_tagcloud'     => true,
//			'public'            => true
//		)
//
//	);
//
//}

add_image_size( 'small', 100, 100 );


/*************************************************/

/* Page Option */

/*************************************************/

if ( function_exists( 'acf_add_options_page' ) ) {


	acf_add_options_page( array(

		'page_title' => 'اعدادات القالب',

		'menu_title' => 'اعدادات القالب',

		'menu_slug' => 'theme-general-settings',

		'capability' => 'edit_posts',

		'update_button' => 'Save Settings',

		'redirect' => false

	) );


}


function mytheme_admin_bar_render() {

	global $wp_admin_bar;

	$wp_admin_bar->add_menu( array(

		'id' => 'themeoptions',

		'title' => ' &#12245; ' . __( 'اعدادات القالب', 'some-textdomain' ),

		'href' => admin_url( 'admin.php?page=theme-general-settings' ),

		'icon' => 'img'

	) );

}


// and we hook our function via

add_action( 'wp_before_admin_bar_render', 'mytheme_admin_bar_render' );


/*************************************************/

/* Sidebar */

/*************************************************/

if ( function_exists( 'register_sidebar' ) ) {

	register_sidebar(

		array(

			'name' => 'sidebar',

			'id' => 'sidebar',

			'description' => 'Sidebar',

			'before_widget' => '<div class="rest-of-news">',

			'after_widget' => '</div>',

			'before_title' => '<h1 class="box-section-title">',

			'after_title' => '</h1>'


		)

	);

}


// sticky post custom page

function wpb_cpt_sticky_at_top( $posts ) {


	// apply it on the archives only

	if ( is_main_query() && is_post_type_archive() ) {

		global $wp_query;


		$sticky_posts = get_option( 'sticky_posts' );

		$num_posts = count( $posts );

		$sticky_offset = 0;


		// Find the sticky posts

		for ( $i = 0; $i < $num_posts; $i ++ ) {


			// Put sticky posts at the top of the posts array

			if ( in_array( $posts[ $i ]->ID, $sticky_posts ) ) {

				$sticky_post = $posts[ $i ];


				// Remove sticky from current position

				array_splice( $posts, $i, 1 );


				// Move to front, after other stickies

				array_splice( $posts, $sticky_offset, 0, array( $sticky_post ) );

				$sticky_offset ++;


				// Remove post from sticky posts array

				$offset = array_search( $sticky_post->ID, $sticky_posts );

				unset( $sticky_posts[ $offset ] );

			}

		}


		// Look for more sticky posts if needed

		if ( ! empty( $sticky_posts ) ) {


			$stickies = get_posts( array(

				'post__in' => $sticky_posts,

				'post_type' => $wp_query->query_vars['post_type'],

				'post_status' => 'publish',

				'nopaging' => true

			) );


			foreach ( $stickies as $sticky_post ) {

				array_splice( $posts, $sticky_offset, 0, array( $sticky_post ) );

				$sticky_offset ++;

			}

		}


	}


	return $posts;

}


add_filter( 'the_posts', 'wpb_cpt_sticky_at_top' );


// Add sticky class in article title to style sticky posts differently


function cpt_sticky_class( $classes ) {

	if ( is_sticky() ) :

		$classes[] = 'sticky';


		return $classes;

	endif;


	return $classes;

}


add_filter( 'post_class', 'cpt_sticky_class' );






add_action( 'admin_init', 'posts_order_wpse_91866' );

function posts_order_wpse_91866() {
	add_post_type_support( 'slider', 'page-attributes' );
}
